# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`cron`](#cron): This class wraps *cron::install* for ease of use
* [`cron::install`](#croninstall): This class ensures that the distro-appropriate cron package is installed. This class should not be used directly under normal circumstances. Instead, use the *cron* class.
* [`cron::service`](#cronservice): This class managed the cron service. This class should not be used directly under normal circumstances. Instead, use the *cron* class.

### Defined types

* [`cron::daily`](#crondaily): This type creates a daily cron job via a file in /etc/cron.d
* [`cron::hourly`](#cronhourly): This type creates an hourly cron job via a file in /etc/cron.d
* [`cron::job`](#cronjob): This type creates a cron job via a file in /etc/cron.d
* [`cron::job::multiple`](#cronjobmultiple): This type creates multiple cron jobs via a single file in /etc/cron.d/
* [`cron::monthly`](#cronmonthly): This type creates a monthly cron job via a file in /etc/cron.d
* [`cron::weekly`](#cronweekly): This type creates a cron job via a file in /etc/cron.d

### Data types

* [`Cron::Date`](#crondate): Valid $date (day of month) parameter to Cron::Job.
* [`Cron::Deb_version`](#crondeb_version): Valid .deb version string. See https://www.debian.org/doc/debian-policy/#s-f-version
* [`Cron::Environment`](#cronenvironment): Valid $environment parameter to Cron::Job.
* [`Cron::Hour`](#cronhour): Valid $hour parameter to Cron::Job.
* [`Cron::Job_ensure`](#cronjob_ensure): Valid $ensure parameter to Cron::Job.
* [`Cron::Jobname`](#cronjobname): Valid $title parameter to Cron::Job. This is the name of the /etc/cron.d/ file. The Ubuntu run-parts manpage specifies (^[a-zA-Z0-9_-]+$). Fo
* [`Cron::Minute`](#cronminute): Valid $minute parameter to Cron::Job.
* [`Cron::Mode`](#cronmode): Valid $mode parameter to Cron::Job.
* [`Cron::Month`](#cronmonth): Valid $month parameter to Cron::Job.
* [`Cron::Monthname`](#cronmonthname): Short-names for each month.
* [`Cron::Package_ensure`](#cronpackage_ensure): Valid $service_ensure parameter to Cron.
* [`Cron::Package_state`](#cronpackage_state): Valid $ensure parameter to Package resource. Excludes version numbers.
* [`Cron::Rpm_version`](#cronrpm_version): Valid .rpm version string. See http://www.perlmonks.org/?node_id=237724
* [`Cron::Run_parts`](#cronrun_parts): Valid element of $crontab_run_parts parameter to Class['cron'].
* [`Cron::Second`](#cronsecond): Valid $second parameter to Cron::Job.
* [`Cron::Service_Enable`](#cronservice_enable): Valid $service_enable parameter to Cron.
* [`Cron::Service_ensure`](#cronservice_ensure): Valid $service_ensure parameter to Cron.
* [`Cron::Special`](#cronspecial): Valid $special parameter to Cron::Job.
* [`Cron::User`](#cronuser): Valid $user parameter to Cron::Job.
* [`Cron::Weekday`](#cronweekday): Valid $weekday parameter to Cron::Job.
* [`Cron::Weekdayname`](#cronweekdayname): Short names for each day of the week.

## Classes

### <a name="cron"></a>`cron`

This class wraps *cron::install* for ease of use

#### Examples

##### simply include the module

```puppet
include cron
```

##### include it but don't manage the cron package

```puppet
class { 'cron':
  manage_package => false,
}
```

#### Parameters

The following parameters are available in the `cron` class:

* [`service_name`](#service_name)
* [`package_name`](#package_name)
* [`manage_package`](#manage_package)
* [`manage_service`](#manage_service)
* [`service_ensure`](#service_ensure)
* [`service_enable`](#service_enable)
* [`users_allow`](#users_allow)
* [`users_deny`](#users_deny)
* [`manage_users_allow`](#manage_users_allow)
* [`manage_users_deny`](#manage_users_deny)
* [`allow_deny_mode`](#allow_deny_mode)
* [`merge`](#merge)
* [`manage_crontab`](#manage_crontab)
* [`crontab_shell`](#crontab_shell)
* [`crontab_path`](#crontab_path)
* [`crontab_mailto`](#crontab_mailto)
* [`crontab_home`](#crontab_home)
* [`crontab_run_parts`](#crontab_run_parts)
* [`package_ensure`](#package_ensure)

##### <a name="service_name"></a>`service_name`

Data type: `String[1]`

Can be set to define a different cron service name.

##### <a name="package_name"></a>`package_name`

Data type: `String[1]`

Can be set to install a different cron package.

##### <a name="manage_package"></a>`manage_package`

Data type: `Boolean`

Can be set to disable package installation.

Default value: ``true``

##### <a name="manage_service"></a>`manage_service`

Data type: `Boolean`

Defines if puppet should manage the service.

Default value: ``true``

##### <a name="service_ensure"></a>`service_ensure`

Data type: `Cron::Service_ensure`

Defines if the service should be running.

Default value: `'running'`

##### <a name="service_enable"></a>`service_enable`

Data type: `Cron::Service_enable`

Defines if the service should be enabled at boot.

Default value: ``true``

##### <a name="users_allow"></a>`users_allow`

Data type: `Array[Cron::User]`

A list of users which are exclusively able to create, edit, display, or remove crontab files. Only used if manage_users_allow == true.

Default value: `[]`

##### <a name="users_deny"></a>`users_deny`

Data type: `Array[Cron::User]`

A list of users which are prohibited from create, edit, display, or remove crontab files. Only used if manage_users_deny == true.

Default value: `[]`

##### <a name="manage_users_allow"></a>`manage_users_allow`

Data type: `Boolean`

If the /etc/cron.allow should be managed.

Default value: ``false``

##### <a name="manage_users_deny"></a>`manage_users_deny`

Data type: `Boolean`

If the /etc/cron.deny should be managed.

Default value: ``false``

##### <a name="allow_deny_mode"></a>`allow_deny_mode`

Data type: `Cron::Mode`

Specify the cron.allow/deny file mode.

Default value: `'0644'`

##### <a name="merge"></a>`merge`

Data type: `Enum['deep', 'first', 'hash', 'unique']`

The `lookup()` merge method to use with cron job hiera lookups.

Default value: `'hash'`

##### <a name="manage_crontab"></a>`manage_crontab`

Data type: `Boolean`

Whether to manage /etc/crontab

Default value: ``false``

##### <a name="crontab_shell"></a>`crontab_shell`

Data type: `Stdlib::Absolutepath`

The value for SHELL in /etc/crontab

Default value: `'/bin/bash'`

##### <a name="crontab_path"></a>`crontab_path`

Data type: `String[1]`

The value for PATH in /etc/crontab

Default value: `'/sbin:/bin:/usr/sbin:/usr/bin'`

##### <a name="crontab_mailto"></a>`crontab_mailto`

Data type: `String[1]`

The value for MAILTO in /etc/crontab

Default value: `'root'`

##### <a name="crontab_home"></a>`crontab_home`

Data type: `Optional[Stdlib::Absolutepath]`

The value for HOME in /etc/crontab

Default value: ``undef``

##### <a name="crontab_run_parts"></a>`crontab_run_parts`

Data type: `Cron::Run_parts`

Define sadditional cron::run_parts resources

Default value: `{}`

##### <a name="package_ensure"></a>`package_ensure`

Data type: `Cron::Package_ensure`



Default value: `'installed'`

### <a name="croninstall"></a>`cron::install`

This class ensures that the distro-appropriate cron package is installed. This class should not be used directly under normal circumstances. Instead, use the *cron* class.

### <a name="cronservice"></a>`cron::service`

This class managed the cron service. This class should not be used directly under normal circumstances. Instead, use the *cron* class.

## Defined types

### <a name="crondaily"></a>`cron::daily`

This type creates a daily cron job via a file in /etc/cron.d

#### Examples

##### create a daily cron job with custom PATH environment variable

```puppet
cron::daily { 'mysql_backup':
  minute      => '1',
  hour        => '3',
  environment => [ 'PATH="/usr/sbin:/usr/bin:/sbin:/bin"' ],
  command     => 'mysqldump -u root my_db >/backups/my_db.sql',
}
```

#### Parameters

The following parameters are available in the `cron::daily` defined type:

* [`command`](#command)
* [`ensure`](#ensure)
* [`minute`](#minute)
* [`hour`](#hour)
* [`environment`](#environment)
* [`user`](#user)
* [`mode`](#mode)
* [`description`](#description)

##### <a name="command"></a>`command`

Data type: `Optional[String[1]]`

The command to execute.

Default value: ``undef``

##### <a name="ensure"></a>`ensure`

Data type: `Cron::Job_ensure`

The state to ensure this resource exists in. Can be absent, present.

Default value: `'present'`

##### <a name="minute"></a>`minute`

Data type: `Cron::Minute`

The minute the cron job should fire on. Can be any valid cron.

Default value: `0`

##### <a name="hour"></a>`hour`

Data type: `Cron::Hour`

The hour the cron job should fire on. Can be any valid cron hour value.

Default value: `0`

##### <a name="environment"></a>`environment`

Data type: `Cron::Environment`

An array of environment variable settings.

Default value: `[]`

##### <a name="user"></a>`user`

Data type: `Cron::User`

The user the cron job should be executed as.

Default value: `'root'`

##### <a name="mode"></a>`mode`

Data type: `Cron::Mode`

The mode to set on the created job file.

Default value: `'0600'`

##### <a name="description"></a>`description`

Data type: `Optional[String]`

Optional short description, which will be included in the cron job file.

Default value: ``undef``

### <a name="cronhourly"></a>`cron::hourly`

This type creates an hourly cron job via a file in /etc/cron.d

#### Examples

##### create a daily cron job with custom PATH environment variable

```puppet
cron::hourly { 'generate_puppetdoc':
  minute      => '1',
  environment => [ 'PATH="/usr/sbin:/usr/bin:/sbin:/bin"' ],
  command     => 'puppet doc >/var/www/puppet_docs.mkd',
}
```

#### Parameters

The following parameters are available in the `cron::hourly` defined type:

* [`command`](#command)
* [`ensure`](#ensure)
* [`minute`](#minute)
* [`environment`](#environment)
* [`user`](#user)
* [`mode`](#mode)
* [`description`](#description)

##### <a name="command"></a>`command`

Data type: `Optional[String[1]]`

The command to execute.

Default value: ``undef``

##### <a name="ensure"></a>`ensure`

Data type: `Cron::Job_ensure`

The state to ensure this resource exists in. Can be absent, present.

Default value: `'present'`

##### <a name="minute"></a>`minute`

Data type: `Cron::Minute`

The minute the cron job should fire on. Can be any valid cron.

Default value: `0`

##### <a name="environment"></a>`environment`

Data type: `Cron::Environment`

An array of environment variable settings.

Default value: `[]`

##### <a name="user"></a>`user`

Data type: `Cron::User`

The user the cron job should be executed as.

Default value: `'root'`

##### <a name="mode"></a>`mode`

Data type: `Cron::Mode`

The mode to set on the created job file.

Default value: `'0600'`

##### <a name="description"></a>`description`

Data type: `Optional[String]`

Optional short description, which will be included in the cron job file.

Default value: ``undef``

### <a name="cronjob"></a>`cron::job`

This type creates a cron job via a file in /etc/cron.d

#### Examples

##### create a cron job

```puppet
cron::job { 'generate_puppetdoc':
  minute      => '01',
  environment => [ 'PATH="/usr/sbin:/usr/bin:/sbin:/bin"' ],
  command     => 'puppet doc /etc/puppet/modules >/var/www/puppet_docs.mkd',
}
```

#### Parameters

The following parameters are available in the `cron::job` defined type:

* [`command`](#command)
* [`ensure`](#ensure)
* [`minute`](#minute)
* [`hour`](#hour)
* [`date`](#date)
* [`month`](#month)
* [`weekday`](#weekday)
* [`special`](#special)
* [`environment`](#environment)
* [`user`](#user)
* [`mode`](#mode)
* [`description`](#description)

##### <a name="command"></a>`command`

Data type: `Optional[String[1]]`

The command to execute.

Default value: ``undef``

##### <a name="ensure"></a>`ensure`

Data type: `Cron::Job_ensure`

The state to ensure this resource exists in. Can be absent, present.

Default value: `'present'`

##### <a name="minute"></a>`minute`

Data type: `Cron::Minute`

The minute the cron job should fire on. Can be any valid cron.

Default value: `'*'`

##### <a name="hour"></a>`hour`

Data type: `Cron::Hour`

The hour the cron job should fire on. Can be any valid cron hour.

Default value: `'*'`

##### <a name="date"></a>`date`

Data type: `Cron::Date`

The date the cron job should fire on. Can be any valid cron date.

Default value: `'*'`

##### <a name="month"></a>`month`

Data type: `Cron::Month`

The month the cron job should fire on. Can be any valid cron month.

Default value: `'*'`

##### <a name="weekday"></a>`weekday`

Data type: `Cron::Weekday`

The day of the week the cron job should fire on. Can be any valid cron weekday value.

Default value: `'*'`

##### <a name="special"></a>`special`

Data type: `Cron::Special`

A crontab specific keyword like 'reboot'.

Default value: ``undef``

##### <a name="environment"></a>`environment`

Data type: `Cron::Environment`

An array of environment variable settings.

Default value: `[]`

##### <a name="user"></a>`user`

Data type: `Cron::User`

The user the cron job should be executed as.

Default value: `'root'`

##### <a name="mode"></a>`mode`

Data type: `Cron::Mode`

The mode to set on the created job file.

Default value: `'0600'`

##### <a name="description"></a>`description`

Data type: `Optional[String]`

Optional short description, which will be included in the cron job file.

Default value: ``undef``

### <a name="cronjobmultiple"></a>`cron::job::multiple`

This type creates multiple cron jobs via a single file in /etc/cron.d/

#### Examples

##### create multiple cron jobs at once

```puppet
cron::job::multiple { 'test':
  jobs => [
    {
      minute      => '55',
      hour        => '5',
      date        => '*',
      month       => '*',
      weekday     => '*',
      user        => 'rmueller',
      command     => '/usr/bin/uname',
    },
    {
      command     => '/usr/bin/sleep 1',
    },
    {
      command     => '/usr/bin/sleep 10',
      special     => 'reboot',
    },
  ],
  environment => [ 'PATH="/usr/sbin:/usr/bin:/sbin:/bin"' ],
}
```

#### Parameters

The following parameters are available in the `cron::job::multiple` defined type:

* [`jobs`](#jobs)
* [`ensure`](#ensure)
* [`environment`](#environment)
* [`mode`](#mode)

##### <a name="jobs"></a>`jobs`

Data type: `Array[Struct[{
        Optional['command']     => String[1],
        Optional['minute']      => Cron::Minute,
        Optional['hour']        => Cron::Hour,
        Optional['date']        => Cron::Date,
        Optional['month']       => Cron::Month,
        Optional['weekday']     => Cron::Weekday,
        Optional['special']     => Cron::Special,
        Optional['environment'] => Cron::Environment,
        Optional['user']        => Cron::User,
        Optional['description'] => String,
  }]]`

A hash of multiple cron jobs using the same structure as cron::job and using the same defaults for each parameter.

##### <a name="ensure"></a>`ensure`

Data type: `Cron::Job_ensure`

The state to ensure this resource exists in. Can be absent, present.

Default value: `'present'`

##### <a name="environment"></a>`environment`

Data type: `Cron::Environment`

An array of environment variable settings.

Default value: `[]`

##### <a name="mode"></a>`mode`

Data type: `Cron::Mode`

The mode to set on the created job file.

Default value: `'0600'`

### <a name="cronmonthly"></a>`cron::monthly`

This type creates a monthly cron job via a file in /etc/cron.d

#### Examples

##### create a cron job that runs monthly on a 28. day at 7 am and 1 minute

```puppet
cron::monthly { 'delete_old_log_files':
  minute      => '1',
  hour        => '7',
  date        => '28',
  environment => [ 'MAILTO="admin@example.com"' ],
  command     => 'find /var/log -type f -ctime +30 -delete',
}
```

#### Parameters

The following parameters are available in the `cron::monthly` defined type:

* [`command`](#command)
* [`ensure`](#ensure)
* [`minute`](#minute)
* [`hour`](#hour)
* [`date`](#date)
* [`environment`](#environment)
* [`user`](#user)
* [`mode`](#mode)
* [`description`](#description)

##### <a name="command"></a>`command`

Data type: `Optional[String[1]]`

The command to execute.

Default value: ``undef``

##### <a name="ensure"></a>`ensure`

Data type: `Cron::Job_ensure`

The state to ensure this resource exists in. Can be absent, present.

Default value: `'present'`

##### <a name="minute"></a>`minute`

Data type: `Cron::Minute`

The minute the cron job should fire on. Can be any valid cron value.

Default value: `0`

##### <a name="hour"></a>`hour`

Data type: `Cron::Hour`

The hour the cron job should fire on. Can be any valid cron hour value.

Default value: `0`

##### <a name="date"></a>`date`

Data type: `Cron::Date`

The date the cron job should fire on. Can be any valid cron date value.

Default value: `1`

##### <a name="environment"></a>`environment`

Data type: `Cron::Environment`

An array of environment variable settings.

Default value: `[]`

##### <a name="user"></a>`user`

Data type: `Cron::User`

The user the cron job should be executed as.

Default value: `'root'`

##### <a name="mode"></a>`mode`

Data type: `Cron::Mode`

The mode to set on the created job file.

Default value: `'0600'`

##### <a name="description"></a>`description`

Data type: `Optional[String]`

Optional short description, which will be included in the cron job file.

Default value: ``undef``

### <a name="cronweekly"></a>`cron::weekly`

This type creates a cron job via a file in /etc/cron.d

#### Examples

##### create a weekly cron that runs on the 7th day at 4 am and 1 minute

```puppet
cron::weekly { 'delete_old_temp_files':
  minute      => '1',
  hour        => '4',
  weekday     => '7',
  environment => [ 'MAILTO="admin@example.com"' ],
  command     => 'find /tmp -type f -ctime +7 -delete',
}
```

#### Parameters

The following parameters are available in the `cron::weekly` defined type:

* [`command`](#command)
* [`ensure`](#ensure)
* [`minute`](#minute)
* [`hour`](#hour)
* [`weekday`](#weekday)
* [`user`](#user)
* [`mode`](#mode)
* [`environment`](#environment)
* [`description`](#description)

##### <a name="command"></a>`command`

Data type: `Optional[String[1]]`

The command to execute.

Default value: ``undef``

##### <a name="ensure"></a>`ensure`

Data type: `Cron::Job_ensure`

The state to ensure this resource exists in. Can be absent, present.

Default value: `'present'`

##### <a name="minute"></a>`minute`

Data type: `Cron::Minute`

The minute the cron job should fire on. Can be any valid cron.

Default value: `0`

##### <a name="hour"></a>`hour`

Data type: `Cron::Hour`

The hour the cron job should fire on. Can be any valid cron hour value.

Default value: `0`

##### <a name="weekday"></a>`weekday`

Data type: `Cron::Weekday`

The day of the week the cron job should fire on. Can be any valid cron weekday value.

Default value: `0`

##### <a name="user"></a>`user`

Data type: `Cron::User`

The user the cron job should be executed as.

Default value: `'root'`

##### <a name="mode"></a>`mode`

Data type: `Cron::Mode`

The mode to set on the created job file.

Default value: `'0600'`

##### <a name="environment"></a>`environment`

Data type: `Cron::Environment`

An array of environment variable settings.

Default value: `[]`

##### <a name="description"></a>`description`

Data type: `Optional[String]`

Optional short description, which will be included in the cron job file.

Default value: ``undef``

## Data types

### <a name="crondate"></a>`Cron::Date`

Valid $date (day of month) parameter to Cron::Job.

Alias of

```puppet
Variant[Integer[1,31], Pattern[/(?x)\A(
    \* ( \/ ( [12][0-9]?|3[01]?|[4-9] ) )?
    |       ( [12][0-9]?|3[01]?|[4-9] ) ( - ( [12][0-9]?|3[01]?|[4-9] ) ( \/ ( [12][0-9]?|3[01]?|[4-9] ) )? )?
       ( ,  ( [12][0-9]?|3[01]?|[4-9] ) ( - ( [12][0-9]?|3[01]?|[4-9] ) ( \/ ( [12][0-9]?|3[01]?|[4-9] ) )? )? )*
  )\z/]]
```

### <a name="crondeb_version"></a>`Cron::Deb_version`

Valid .deb version string.
See https://www.debian.org/doc/debian-policy/#s-f-version

Alias of

```puppet
Pattern[/(?i:\A(((0|[1-9][0-9]*):)?[0-9]([a-z0-9.+-~]*|[a-z0-9.+~]*-[a-z0-9+.~]+))\z)/]
```

### <a name="cronenvironment"></a>`Cron::Environment`

Valid $environment parameter to Cron::Job.

Alias of

```puppet
Array[Pattern[/(?i:\A[a-z_][a-z0-9_]*=[^\0]*\z)/]]
```

### <a name="cronhour"></a>`Cron::Hour`

Valid $hour parameter to Cron::Job.

Alias of

```puppet
Variant[Integer[0,23], Pattern[/(?x)\A(
    \* ( \/ ( 1[0-9]|2[0-3]|[1-9] ) )?
    |       ( 1?[0-9]|2[0-3] ) ( - ( 1?[0-9]|2[0-3] ) ( \/ ( 1[0-9]|2[0-3]|[1-9] ) )? )?
        ( , ( 1?[0-9]|2[0-3] ) ( - ( 1?[0-9]|2[0-3] ) ( \/ ( 1[0-9]|2[0-3]|[1-9] ) )? )? )*
  )\z/]]
```

### <a name="cronjob_ensure"></a>`Cron::Job_ensure`

Valid $ensure parameter to Cron::Job.

Alias of

```puppet
Enum['absent', 'present']
```

### <a name="cronjobname"></a>`Cron::Jobname`

Valid $title parameter to Cron::Job.
This is the name of the /etc/cron.d/ file.
The Ubuntu run-parts manpage specifies (^[a-zA-Z0-9_-]+$).
For Cronie, the documentation is (unfortunately) in the code:
- Ignore files starting with "." or "#"
- Ignore the CRON_HOSTNAME file (default ".cron.hostname").
- Ignore files whose length is zero or greater than NAME_MAX (default 255).
- Ignore files whose name ends in "~".
- Ignore files whose name ends in ".rpmsave", ".rpmorig", or ".rpmnew".
We will use the most restrictive combination.
See http://manpages.ubuntu.com/manpages/zesty/en/man8/run-parts.8.html
See https://github.com/cronie-crond/cronie/blob/master/src/database.c#L625

Alias of

```puppet
Pattern[/(?i:\A[a-z0-9_-]{1,255}\z)/]
```

### <a name="cronminute"></a>`Cron::Minute`

Valid $minute parameter to Cron::Job.

Alias of

```puppet
Variant[Integer[0,59], Pattern[/(?x)\A(
    \* ( \/ ( [1-5][0-9]?|[6-9] ) )?
    |         [1-5]?[0-9] ( - [1-5]?[0-9] ( \/ ( [1-5][0-9]?|[6-9] ) )? )?
        ( ,   [1-5]?[0-9] ( - [1-5]?[0-9] ( \/ ( [1-5][0-9]?|[6-9] ) )? )? )*
  )\z/]]
```

### <a name="cronmode"></a>`Cron::Mode`

Valid $mode parameter to Cron::Job.

Alias of

```puppet
Pattern[/\A[0-7]{4}\z/]
```

### <a name="cronmonth"></a>`Cron::Month`

Valid $month parameter to Cron::Job.

Alias of

```puppet
Variant[Cron::Monthname, Integer[1,12], Pattern[/(?x)\A(
    \* ( \/ ( 1[012]?|[2-9] ) )?
    |       ( 1[012]?|[2-9] ) ( - ( 1[012]?|[2-9] ) ( \/ ( 1[012]?|[2-9] ) )? )?
        ( , ( 1[012]?|[2-9] ) ( - ( 1[012]?|[2-9] ) ( \/ ( 1[012]?|[2-9] ) )? )? )*
  )\z/]]
```

### <a name="cronmonthname"></a>`Cron::Monthname`

Short-names for each month.

Alias of

```puppet
Enum['Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec']
```

### <a name="cronpackage_ensure"></a>`Cron::Package_ensure`

Valid $service_ensure parameter to Cron.

Alias of

```puppet
Variant[Cron::Package_state, Cron::Deb_version, Cron::Rpm_version]
```

### <a name="cronpackage_state"></a>`Cron::Package_state`

Valid $ensure parameter to Package resource. Excludes version numbers.

Alias of

```puppet
Enum['absent', 'installed', 'held', 'latest', 'present', 'purged']
```

### <a name="cronrpm_version"></a>`Cron::Rpm_version`

Valid .rpm version string.
See http://www.perlmonks.org/?node_id=237724

Alias of

```puppet
Pattern[/\A[^-]+(-[^-])?\z/]
```

### <a name="cronrun_parts"></a>`Cron::Run_parts`

Valid element of $crontab_run_parts parameter to Class['cron'].

Alias of

```puppet
Hash[Cron::Jobname, Struct[{
    NotUndef['user']       => Cron::User,
    Optional['minute']     => Cron::Minute,
    Optional['hour']       => Cron::Hour,
    Optional['dayofmonth'] => Cron::Date,
    Optional['month']      => Cron::Month,
    Optional['dayofweek']  => Cron::Weekday,
  }]]
```

### <a name="cronsecond"></a>`Cron::Second`

Valid $second parameter to Cron::Job.

Alias of

```puppet
Cron::Minute
```

### <a name="cronservice_enable"></a>`Cron::Service_Enable`

Valid $service_enable parameter to Cron.

Alias of

```puppet
Variant[Boolean, Enum['manual','mask']]
```

### <a name="cronservice_ensure"></a>`Cron::Service_ensure`

Valid $service_ensure parameter to Cron.

Alias of

```puppet
Variant[Boolean, Enum['running','stopped']]
```

### <a name="cronspecial"></a>`Cron::Special`

Valid $special parameter to Cron::Job.

Alias of

```puppet
Optional[Enum['annually',
    'daily',
    'hourly',
    'midnight',
    'monthly',
    'reboot',
    'weekly',
    'yearly',
  ]]
```

### <a name="cronuser"></a>`Cron::User`

Valid $user parameter to Cron::Job.

Alias of

```puppet
Pattern[/(?i:\A\w[a-z0-9_\.-]{0,30}[a-z0-9_$-]\z)/]
```

### <a name="cronweekday"></a>`Cron::Weekday`

Valid $weekday parameter to Cron::Job.

Alias of

```puppet
Variant[Cron::Weekdayname, Integer[0,7], Pattern[/(?x)\A(
    \* ( \/ [1-7] )?
    |       [0-7] ( - [0-7] ( \/ [1-7] )? )?
        ( , [0-7] ( - [0-7] ( \/ [1-7] )? )? )*
  )\z/]]
```

### <a name="cronweekdayname"></a>`Cron::Weekdayname`

Short names for each day of the week.

Alias of

```puppet
Enum['Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat']
```

